summaryrefslogtreecommitdiffstats
path: root/testsuites/libtests/block08/bdbuf_test1_1.c
diff options
context:
space:
mode:
authorSebastian Huber <sebastian.huber@embedded-brains.de>2010-05-17 08:34:55 +0000
committerSebastian Huber <sebastian.huber@embedded-brains.de>2010-05-17 08:34:55 +0000
commit377c0cb0e3447958a2a112f8d9c824d82d471fae (patch)
tree41757938de30fd18445a25b11437df5dfb6f00c2 /testsuites/libtests/block08/bdbuf_test1_1.c
parent2010-05-17 Oleg Kravtsov <Oleg.Kravtsov@oktetlabs.ru> (diff)
downloadrtems-377c0cb0e3447958a2a112f8d9c824d82d471fae.tar.bz2
2010-05-17 Sebastian Huber <sebastian.huber@embedded-brains.de>
PR 1433/cpukit * block08/bdbuf_tests.c: Enabled tests 1.1, 1.2 and 1.3. * block08/bdbuf_test1_1.c, block08/bdbuf_test1_2.c, block08/bdbuf_test1_3.c: Use RTEMS_IO_ERROR instead of RTEMS_NO_MEMORY.
Diffstat (limited to 'testsuites/libtests/block08/bdbuf_test1_1.c')
-rw-r--r--testsuites/libtests/block08/bdbuf_test1_1.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/testsuites/libtests/block08/bdbuf_test1_1.c b/testsuites/libtests/block08/bdbuf_test1_1.c
index 1152af25b7..6e2d2fdd83 100644
--- a/testsuites/libtests/block08/bdbuf_test1_1.c
+++ b/testsuites/libtests/block08/bdbuf_test1_1.c
@@ -77,10 +77,10 @@ bdbuf_test1_1_main()
* Check that rtems_bdbuf_read() returns status obtained
* from device driver via asynchonous notification.
* On this step device driver returns 0 from ioctl() call,
* but notification callback is called with RTEMS_NO_MEMORY status.
*/
WAIT_DRV_MSG(&msg);
- SEND_DRV_MSG(0, 0, RTEMS_NO_MEMORY, EFAULT);
+ SEND_DRV_MSG(0, 0, RTEMS_IO_ERROR, EFAULT);
WAIT_THREAD_SYNC(1);
TEST_CHECK_RESULT("6");
@@ -130,11 +130,11 @@ bdbuf_test1_1_thread1(rtems_task_argument arg)
/*
* Step 5-6:
* Read operation fails with RTEMS_NO_MEMORY code.
* The function shall not update user pointer.
*/
rc = rtems_bdbuf_read(test_dev, TEST_BLK_NUM, &bd2);
- if (rc != RTEMS_NO_MEMORY || bd2 != NULL)
+ if (rc != RTEMS_IO_ERROR || bd2 != NULL)
{
TEST_FAILED();
}
@@ -77,10 +77,10 @@ bdbuf_test1_1_main()
* from device driver via asynchonous notification.
* On this step device driver returns 0 from ioctl() call,
- * but notification callback is called with RTEMS_NO_MEMORY status.
+ * but notification callback is called with RTEMS_IO_ERROR status.
*/
WAIT_DRV_MSG(&msg);
@@ -130,11 +130,11 @@ bdbuf_test1_1_thread1(rtems_task_argument arg)
/*
* Step 5-6:
- * Read operation fails with RTEMS_NO_MEMORY code.
+ * Read operation fails with RTEMS_IO_ERROR code.
* The function shall not update user pointer.
*/